@@ -39,9 +39,9 @@ class ScheduleCommand(HueObject):
 
 
 class Schedule(HueObject):
-    def __init__(self, identity: str, uri: str) -> None:
-        self.command = ScheduleCommand("", uri)
-        super().__init__(identity, uri)
+    def __init__(self, identity: str, uri: str, raw: dict = None) -> None:
+        self.command = ScheduleCommand("", uri, raw=raw)
+        super().__init__(identity, uri, raw=raw)
 
     def load_data(self, raw: dict = None) -> None:
         super().load_data(raw)
